==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkSpatialRepresentationFilter.java <==
// java wrapper for vtkSpatialRepresentationFilter object
//

package vtk;
import vtk.*;

public class vtkSpatialRepresentationFilter extends vtkMultiBlockDataSetAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetSpatialRepresentation_2(vtkLocator id0);
  public void SetSpatialRepresentation(vtkLocator id0)
    { SetSpatialRepresentation_2(id0); }

  private native long GetSpatialRepresentation_3();
  public vtkLocator GetSpatialRepresentation() {
    long temp = GetSpatialRepresentation_3();

    if (temp == 0) return null;
    return (vtkLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetMaximumLevel_4();
  public int GetMaximumLevel()
    { return GetMaximumLevel_4(); }

  private native void AddLevel_5(int id0);
  public void AddLevel(int id0)
    { AddLevel_5(id0); }

  private native void ResetLevels_6();
  public void ResetLevels()
    { ResetLevels_6(); }

  private native void SetGenerateLeaves_7(boolean id0);
  public void SetGenerateLeaves(boolean id0)
    { SetGenerateLeaves_7(id0); }

  private native boolean GetGenerateLeaves_8();
  public boolean GetGenerateLeaves()
    { return GetGenerateLeaves_8(); }

  private native void GenerateLeavesOn_9();
  public void GenerateLeavesOn()
    { GenerateLeavesOn_9(); }

  private native void GenerateLeavesOff_10();
  public void GenerateLeavesOff()
    { GenerateLeavesOff_10(); }

  public vtkSpatialRepresentationFilter() { super(); }

  public vtkSpatialRepresentationFilter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-13-armv7h.pkg.tar.xz: vtk/vtkSpatialRepresentationFilter.java <==
// java wrapper for vtkSpatialRepresentationFilter object
//

package vtk;
import vtk.*;

public class vtkSpatialRepresentationFilter extends vtkMultiBlockDataSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetSpatialRepresentation_2(vtkLocator id0);
  public void SetSpatialRepresentation(vtkLocator id0)
    { SetSpatialRepresentation_2(id0); }

  private native long GetSpatialRepresentation_3();
  public vtkLocator GetSpatialRepresentation() {
    long temp = GetSpatialRepresentation_3();

    if (temp == 0) return null;
    return (vtkLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetMaximumLevel_4();
  public int GetMaximumLevel()
    { return GetMaximumLevel_4(); }

  private native void AddLevel_5(int id0);
  public void AddLevel(int id0)
    { AddLevel_5(id0); }

  private native void ResetLevels_6();
  public void ResetLevels()
    { ResetLevels_6(); }

  private native void SetGenerateLeaves_7(boolean id0);
  public void SetGenerateLeaves(boolean id0)
    { SetGenerateLeaves_7(id0); }

  private native boolean GetGenerateLeaves_8();
  public boolean GetGenerateLeaves()
    { return GetGenerateLeaves_8(); }

  private native void GenerateLeavesOn_9();
  public void GenerateLeavesOn()
    { GenerateLeavesOn_9(); }

  private native void GenerateLeavesOff_10();
  public void GenerateLeavesOff()
    { GenerateLeavesOff_10(); }

  public vtkSpatialRepresentationFilter() { super(); }

  public vtkSpatialRepresentationFilter(long id) { super(id); }
  public native long   VTKInit();

}
